@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 # vim:ts=4:sw=4:expandtab
 #
-# i3 - an improved dynamic tiling window manager
+# i3 - an improved tiling window manager
 # © 2009 Michael Stapelberg and contributors (see also: LICENSE)
 #
 # generate-command-parser.pl: script to generate parts of the command parser
@@ -147,11 +147,12 @@ for my $state (@keys) {
         $next_state ||= 'INITIAL';
         my $fmt = $cmd;
         # Replace the references to identified literals (like $workspace) with
-        # calls to get_string(). Also replaces state names (like FOR_WINDOW)
-        # with their ID (useful for cfg_criteria_init(FOR_WINDOW) e.g.).
+        # calls to parser_get_string(). Also replaces state names (like
+        # FOR_WINDOW) with their ID (useful for cfg_criteria_init(FOR_WINDOW)
+        # e.g.).
         $cmd =~ s/$_/$statenum{$_}/g for @keys;
-        $cmd =~ s/\$([a-z_]+)/get_string(stack, "$1")/g;
-        $cmd =~ s/\&([a-z_]+)/get_long(stack, "$1")/g;
+        $cmd =~ s/\$([a-z_]+)/parser_get_string(stack, "$1")/g;
+        $cmd =~ s/\&([a-z_]+)/parser_get_long(stack, "$1")/g;
         # For debugging/testing, we print the call using printf() and thus need
         # to generate a format string. The format uses %d for <number>s,
         # literal numbers or state IDs and %s for NULL, <string>s and literal
@@ -228,8 +229,15 @@ for my $state (@keys) {
             ($call_identifier) = ($next_state =~ /^call ([0-9]+)$/);
             $next_state = '__CALL';
         }
-        my $identifier = $token->{identifier};
-        say $tokfh qq|    { "$token_name", "$identifier", $next_state, { $call_identifier } },|;
+        my $identifier;
+        # Set $identifier to NULL if there is no identifier
+        if ($token->{identifier} eq ""){
+            $identifier = "NULL"
+        }
+        else{
+            $identifier = qq|"$token->{identifier}"|;
+        }
+        say $tokfh qq|    { "$token_name", $identifier, $next_state, { $call_identifier } },|;
     }
     say $tokfh '};';
 }
