@@ -28,7 +28,7 @@ char *current_socketpath = NULL;
 TAILQ_HEAD(ipc_client_head, ipc_client) all_clients = TAILQ_HEAD_INITIALIZER(all_clients);
 
 static void ipc_client_timeout(EV_P_ ev_timer *w, int revents);
-static void ipc_socket_writeable_cb(EV_P_ struct ev_io *w, int revents);
+static void ipc_socket_writeable_cb(EV_P_ ev_io *w, int revents);
 
 static ev_tstamp kill_timeout = 10.0;
 
@@ -66,7 +66,7 @@ static void ipc_push_pending(ipc_client *client) {
     ev_io_start(main_loop, client->write_callback);
 
     if (!client->timeout) {
-        struct ev_timer *timeout = scalloc(1, sizeof(struct ev_timer));
+        ev_timer *timeout = scalloc(1, sizeof(struct ev_timer));
         ev_timer_init(timeout, ipc_client_timeout, kill_timeout, 0.);
         timeout->data = client;
         client->timeout = timeout;
@@ -192,9 +192,8 @@ static void ipc_send_shutdown_event(shutdown_reason_t reason) {
 void ipc_shutdown(shutdown_reason_t reason, int exempt_fd) {
     ipc_send_shutdown_event(reason);
 
-    ipc_client *current;
     while (!TAILQ_EMPTY(&all_clients)) {
-        current = TAILQ_FIRST(&all_clients);
+        ipc_client *current = TAILQ_FIRST(&all_clients);
         if (current->fd != exempt_fd) {
             shutdown(current->fd, SHUT_RDWR);
         }
@@ -359,7 +358,7 @@ static void dump_binding(yajl_gen gen, Binding *bind) {
     y(map_close);
 }
 
-void dump_node(yajl_gen gen, struct Con *con, bool inplace_restart) {
+void dump_node(yajl_gen gen, Con *con, bool inplace_restart) {
     y(map_open);
     ystr("id");
     y(integer, (uintptr_t)con);
@@ -910,10 +909,12 @@ static void dump_bar_config(yajl_gen gen, Barconfig *config) {
 }
 
 IPC_HANDLER(tree) {
+    char *prev_locale = sstrdup(setlocale(LC_NUMERIC, NULL));
     setlocale(LC_NUMERIC, "C");
     yajl_gen gen = ygenalloc();
     dump_node(gen, croot, false);
-    setlocale(LC_NUMERIC, "");
+    setlocale(LC_NUMERIC, prev_locale);
+    free(prev_locale);
 
     const unsigned char *payload;
     ylength length;
@@ -1235,20 +1236,15 @@ static int add_subscription(void *extra, const unsigned char *s,
  *
  */
 IPC_HANDLER(subscribe) {
-    yajl_handle p;
-    yajl_status stat;
-
     /* Setup the JSON parser */
     static yajl_callbacks callbacks = {
         .yajl_string = add_subscription,
     };
 
-    p = yalloc(&callbacks, (void *)client);
-    stat = yajl_parse(p, (const unsigned char *)message, message_size);
+    const yajl_handle p = yalloc(&callbacks, client);
+    const yajl_status stat = yajl_parse(p, message, message_size);
     if (stat != yajl_status_ok) {
-        unsigned char *err;
-        err = yajl_get_error(p, true, (const unsigned char *)message,
-                             message_size);
+        unsigned char *err = yajl_get_error(p, true, message, message_size);
         ELOG("YAJL parse error: %s\n", err);
         yajl_free_error(p, err);
 
@@ -1371,24 +1367,18 @@ static int _sync_json_int(void *extra, long long val) {
 }
 
 IPC_HANDLER(sync) {
-    yajl_handle p;
-    yajl_status stat;
-
     /* Setup the JSON parser */
     static yajl_callbacks callbacks = {
         .yajl_map_key = _sync_json_key,
         .yajl_integer = _sync_json_int,
     };
 
-    struct sync_state state;
-    memset(&state, '\0', sizeof(struct sync_state));
-    p = yalloc(&callbacks, (void *)&state);
-    stat = yajl_parse(p, (const unsigned char *)message, message_size);
+    struct sync_state state = {0};
+    yajl_handle p = yalloc(&callbacks, &state);
+    yajl_status stat = yajl_parse(p, message, message_size);
     FREE(state.last_key);
     if (stat != yajl_status_ok) {
-        unsigned char *err;
-        err = yajl_get_error(p, true, (const unsigned char *)message,
-                             message_size);
+        unsigned char *err = yajl_get_error(p, true, message, message_size);
         ELOG("YAJL parse error: %s\n", err);
         yajl_free_error(p, err);
 
@@ -1451,11 +1441,11 @@ handler_t handlers[13] = {
  * at the moment.
  *
  */
-static void ipc_receive_message(EV_P_ struct ev_io *w, int revents) {
+static void ipc_receive_message(EV_P_ ev_io *w, int revents) {
     uint32_t message_type;
     uint32_t message_length;
     uint8_t *message = NULL;
-    ipc_client *client = (ipc_client *)w->data;
+    ipc_client *client = w->data;
     assert(client->fd == w->fd);
 
     int ret = ipc_recv_message(w->fd, &message_type, &message_length, &message);
@@ -1487,7 +1477,7 @@ static void ipc_receive_message(EV_P_ struct ev_io *w, int revents) {
 static void ipc_client_timeout(EV_P_ ev_timer *w, int revents) {
     /* No need to be polite and check for writeability, the other callback would
      * have been called by now. */
-    ipc_client *client = (ipc_client *)w->data;
+    ipc_client *client = w->data;
 
     char *cmdline = NULL;
 #if defined(__linux__) && defined(SO_PEERCRED)
@@ -1547,7 +1537,7 @@ static void ipc_socket_writeable_cb(EV_P_ ev_io *w, int revents) {
  * the list of clients.
  *
  */
-void ipc_new_client(EV_P_ struct ev_io *w, int revents) {
+void ipc_new_client(EV_P_ ev_io *w, int revents) {
     struct sockaddr_un peer;
     socklen_t len = sizeof(struct sockaddr_un);
     int fd;
@@ -1578,12 +1568,12 @@ ipc_client *ipc_new_client_on_fd(EV_P_ int fd) {
     ipc_client *client = scalloc(1, sizeof(ipc_client));
     client->fd = fd;
 
-    client->read_callback = scalloc(1, sizeof(struct ev_io));
+    client->read_callback = scalloc(1, sizeof(ev_io));
     client->read_callback->data = client;
     ev_io_init(client->read_callback, ipc_receive_message, fd, EV_READ);
     ev_io_start(EV_A_ client->read_callback);
 
-    client->write_callback = scalloc(1, sizeof(struct ev_io));
+    client->write_callback = scalloc(1, sizeof(ev_io));
     client->write_callback->data = client;
     ev_io_init(client->write_callback, ipc_socket_writeable_cb, fd, EV_WRITE);
 
@@ -1597,6 +1587,7 @@ ipc_client *ipc_new_client_on_fd(EV_P_ int fd) {
  * generator. Free with yajl_gen_free().
  */
 yajl_gen ipc_marshal_workspace_event(const char *change, Con *current, Con *old) {
+    char *prev_locale = sstrdup(setlocale(LC_NUMERIC, NULL));
     setlocale(LC_NUMERIC, "C");
     yajl_gen gen = ygenalloc();
 
@@ -1621,7 +1612,8 @@ yajl_gen ipc_marshal_workspace_event(const char *change, Con *current, Con *old)
 
     y(map_close);
 
-    setlocale(LC_NUMERIC, "");
+    setlocale(LC_NUMERIC, prev_locale);
+    free(prev_locale);
 
     return gen;
 }
@@ -1651,6 +1643,7 @@ void ipc_send_window_event(const char *property, Con *con) {
     DLOG("Issue IPC window %s event (con = %p, window = 0x%08x)\n",
          property, con, (con->window ? con->window->id : XCB_WINDOW_NONE));
 
+    char *prev_locale = sstrdup(setlocale(LC_NUMERIC, NULL));
     setlocale(LC_NUMERIC, "C");
     yajl_gen gen = ygenalloc();
 
@@ -1670,7 +1663,8 @@ void ipc_send_window_event(const char *property, Con *con) {
 
     ipc_send_event("window", I3_IPC_EVENT_WINDOW, (const char *)payload);
     y(free);
-    setlocale(LC_NUMERIC, "");
+    setlocale(LC_NUMERIC, prev_locale);
+    free(prev_locale);
 }
 
 /*
@@ -1678,6 +1672,7 @@ void ipc_send_window_event(const char *property, Con *con) {
  */
 void ipc_send_barconfig_update_event(Barconfig *barconfig) {
     DLOG("Issue barconfig_update event for id = %s\n", barconfig->id);
+    char *prev_locale = sstrdup(setlocale(LC_NUMERIC, NULL));
     setlocale(LC_NUMERIC, "C");
     yajl_gen gen = ygenalloc();
 
@@ -1689,7 +1684,8 @@ void ipc_send_barconfig_update_event(Barconfig *barconfig) {
 
     ipc_send_event("barconfig_update", I3_IPC_EVENT_BARCONFIG_UPDATE, (const char *)payload);
     y(free);
-    setlocale(LC_NUMERIC, "");
+    setlocale(LC_NUMERIC, prev_locale);
+    free(prev_locale);
 }
 
 /*
@@ -1698,6 +1694,7 @@ void ipc_send_barconfig_update_event(Barconfig *barconfig) {
 void ipc_send_binding_event(const char *event_type, Binding *bind, const char *modename) {
     DLOG("Issue IPC binding %s event (sym = %s, code = %d)\n", event_type, bind->symbol, bind->keycode);
 
+    char *prev_locale = sstrdup(setlocale(LC_NUMERIC, NULL));
     setlocale(LC_NUMERIC, "C");
 
     yajl_gen gen = ygenalloc();
@@ -1726,7 +1723,8 @@ void ipc_send_binding_event(const char *event_type, Binding *bind, const char *m
     ipc_send_event("binding", I3_IPC_EVENT_BINDING, (const char *)payload);
 
     y(free);
-    setlocale(LC_NUMERIC, "");
+    setlocale(LC_NUMERIC, prev_locale);
+    free(prev_locale);
 }
 
 /*
