@@ -504,7 +504,7 @@ void workspace_show(Con *workspace) {
         if (focused->urgency_timer == NULL) {
             DLOG("Deferring reset of urgency flag of con %p on newly shown workspace %p\n",
                  focused, workspace);
-            focused->urgency_timer = scalloc(1, sizeof(struct ev_timer));
+            focused->urgency_timer = scalloc(1, sizeof(ev_timer));
             /* use a repeating timer to allow for easy resets */
             ev_timer_init(focused->urgency_timer, workspace_defer_update_urgent_hint_cb,
                           config.workspace_urgency_timer, config.workspace_urgency_timer);
@@ -1039,9 +1039,8 @@ Con *workspace_encapsulate(Con *ws) {
 
     DLOG("Moving children of workspace %p / %s into container %p\n",
          ws, ws->name, new);
-    Con *child;
     while (!TAILQ_EMPTY(&(ws->nodes_head))) {
-        child = TAILQ_FIRST(&(ws->nodes_head));
+        Con *child = TAILQ_FIRST(&(ws->nodes_head));
         con_detach(child);
         con_attach(child, new, true);
     }
